@@ -55,7 +55,6 @@ CHMGenerator::CHMGenerator( QObject *parent, const QVariantList &args )
 
     m_syncGen=0;
     m_file=0;
-    m_pixmapRequestZoom=1;
     m_request = 0;
 }
 
@@ -79,6 +78,9 @@ bool CHMGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
     
     // fill m_docSyn
     QMap<int, QDomElement> lastIndentElement;
+    QMap<QString, int> tmpPageList;
+    int pageNum = 0;
+
     foreach(const LCHMParsedEntry &e, topics)
     {
         QDomElement item = m_docSyn.createElement(e.name);
@@ -88,6 +90,11 @@ bool CHMGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
             if (url.contains(QChar::fromLatin1('%')))
                 url = QString::fromUtf8(QByteArray::fromPercentEncoding(url.toUtf8()));
             item.setAttribute(QStringLiteral("ViewportName"), url);
+            if(!tmpPageList.contains(url))
+            {//add a page only once
+                tmpPageList.insert(url, pageNum);
+                pageNum++;
+            }
         }
         item.setAttribute(QStringLiteral("Icon"), e.imageid);
         if (e.indent == 0) m_docSyn.appendChild(item);
@@ -96,12 +103,13 @@ bool CHMGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
     }
     
     // fill m_urlPage and m_pageUrl
-    int pageNum = 0;
     QStringList pageList;
     m_file->enumerateFiles(&pageList);
     const QString home = m_file->homeUrl();
     if (home != QLatin1String("/"))
         pageList.prepend(home);
+    m_pageUrl.resize(pageNum);
+
     foreach (const QString &url, pageList)
     {
         const QString urlLower = url.toLower();
@@ -109,15 +117,22 @@ bool CHMGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
             continue;
 
         int pos = url.indexOf (QLatin1Char(('#')));
+        // insert the url into the maps, but insert always the variant without the #ref part
         QString tmpUrl = pos == -1 ? url : url.left(pos);
 
         // url already there, abort insertion
         if (m_urlPage.contains(tmpUrl)) continue;
 
-        // insert the url into the maps, but insert always the variant without the #ref part
-        m_urlPage.insert(tmpUrl, pageNum);
-        m_pageUrl.append(tmpUrl);
-        pageNum++;
+        int foundPage = tmpPageList.value(tmpUrl, -1);
+        if (foundPage != -1 ) {
+            m_urlPage.insert(tmpUrl, foundPage);
+            m_pageUrl[foundPage] = tmpUrl;
+        } else {
+            //add pages not present in toc
+            m_urlPage.insert(tmpUrl, pageNum);
+            m_pageUrl.append(tmpUrl);
+            pageNum++;
+        }
     }
 
     pagesVector.resize(m_pageUrl.count());
@@ -132,7 +147,7 @@ bool CHMGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
 
     for (int i = 0; i < m_pageUrl.count(); ++i)
     {
-        preparePageForSyncOperation(100, m_pageUrl.at(i));
+        preparePageForSyncOperation(m_pageUrl.at(i));
         pagesVector[ i ] = new Okular::Page (i, m_syncGen->view()->contentsWidth(),
             m_syncGen->view()->contentsHeight(), Okular::Rotation0 );
     }
@@ -161,11 +176,11 @@ bool CHMGenerator::doCloseDocument()
     return true;
 }
 
-void CHMGenerator::preparePageForSyncOperation( int zoom , const QString & url)
+void CHMGenerator::preparePageForSyncOperation(const QString & url)
 {
     QString pAddress= QStringLiteral("ms-its:") + m_fileName + QStringLiteral("::") + url;
     m_chmUrl = url;
-    m_syncGen->setZoomFactor(zoom);
+
     m_syncGen->openUrl(QUrl(pAddress));
     m_syncGen->view()->layout();
 
@@ -183,7 +198,7 @@ void CHMGenerator::slotCompleted()
         return;
 
     QImage image( m_request->width(), m_request->height(), QImage::Format_ARGB32 );
-    image.fill( qRgb( 255, 255, 255 ) );
+    image.fill( Qt::white );
 
     QPainter p( &image );
     QRect r( 0, 0, m_request->width(), m_request->height() );
@@ -193,9 +208,6 @@ void CHMGenerator::slotCompleted()
 
     p.end();
 
-    if ( m_pixmapRequestZoom > 1 )
-        m_pixmapRequestZoom = 1;
-
     if ( !m_textpageAddedList.at( m_request->pageNumber() ) ) {
         additionalRequestData();
         m_textpageAddedList[ m_request->pageNumber() ] = true;
@@ -245,23 +257,13 @@ void CHMGenerator::generatePixmap( Okular::PixmapRequest * request )
 {
     int requestWidth = request->width();
     int requestHeight = request->height();
-    if (requestWidth<300)
-    {
-        m_pixmapRequestZoom=900/requestWidth;
-        requestWidth*=m_pixmapRequestZoom;
-        requestHeight*=m_pixmapRequestZoom;
-    }
 
     userMutex()->lock();
     QString url= m_pageUrl[request->pageNumber()];
-    int zoom = qRound( qMax( static_cast<double>(requestWidth)/static_cast<double>(request->page()->width())
-        , static_cast<double>(requestHeight)/static_cast<double>(request->page()->height())
-        ) ) * 100;
 
     QString pAddress= QStringLiteral("ms-its:") + m_fileName + QStringLiteral("::") + url;
     m_chmUrl = url;
-    m_syncGen->setZoomFactor(zoom);
-    m_syncGen->view()->resize(requestWidth,requestHeight);
+    m_syncGen->view()->resizeContents(requestWidth,requestHeight);
     m_request=request;
     // will emit openURL without problems
     m_syncGen->openUrl ( QUrl(pAddress) );
@@ -411,10 +413,10 @@ void CHMGenerator::additionalRequestData()
 Okular::TextPage* CHMGenerator::textPage( Okular::Page * page )
 {
     userMutex()->lock();
-    const int zoom = 100;
+
     m_syncGen->view()->resize(page->width(), page->height());
     
-    preparePageForSyncOperation(zoom, m_pageUrl[page->number()]);
+    preparePageForSyncOperation(m_pageUrl[page->number()]);
     Okular::TextPage *tp=new Okular::TextPage();
     recursiveExploreNodes( m_syncGen->htmlDocument(), tp);
     userMutex()->unlock();
